configalchemy package
======================

BaseConfig module
---------------------------

.. autoclass:: configalchemy.BaseConfig
    :members:

ApolloBaseConfig module
---------------------------

.. autoclass:: configalchemy.contrib.apollo.ApolloBaseConfig
    :members:
